@@ -719,6 +719,19 @@ class FBGNeedle( Needle ):
 
     # generate_chaa
 
+    @classmethod
+    def _json_data_is_of_class(cls, json_data: dict):
+        """ Checks if dict of json data fits this class"""
+
+        conditions = [
+            'Sensor Locations' in json_data.keys(),
+            '# channels' in json_data.keys(),
+        ]
+
+        return all(conditions)
+
+    # _json_data_is_of_class
+
     @classmethod
     def from_dict(cls, data: dict, **kwargs):
         # insert the sensor locations in order of AA
@@ -796,8 +809,8 @@ class FBGNeedle( Needle ):
     
     # from_dict
 
-    @classmethod
-    def load_json( cls, filename: str ):
+    @staticmethod
+    def load_json( filename: str ):
         """ 
         This function is used to load a FBGNeedle class from a saved JSON file.
         
@@ -814,7 +827,11 @@ class FBGNeedle( Needle ):
 
         # with
 
-        return cls.from_dict(data)
+        needle_cls = FBGNeedle
+        if MCFNeedle._json_data_is_of_class(data):
+            needle_cls = MCFNeedle
+
+        return needle_cls.from_dict(data)
 
     # load_json
 
@@ -983,6 +1000,15 @@ class MCFNeedle( FBGNeedle ):
 
     # __assignments_centralcore
 
+    @classmethod
+    def _json_data_is_of_class( cls, json_data: dict ):
+        conditions = [
+            super()._json_data_is_of_class(json_data),
+            'Central Core CH' in json_data.keys(),
+        ]
+
+        return all(conditions)
+
     @classmethod
     def from_dict(cls, data: dict, **kwargs):
         central_core_ch =  data["Central Core CH"]
@@ -992,6 +1018,72 @@ class MCFNeedle( FBGNeedle ):
 
     # from_dict
 
+    def curvatures_processed( self, proc_signals: Union[ dict, np.ndarray ] ) -> Union[ dict, np.ndarray ]:
+        """ Determine the curvatures from signals input
+
+            Args:
+                proc_signals: {AA_index: processed signal} must be processed and temperature compensated
+
+        """
+
+        if isinstance( proc_signals, dict ):
+            curvatures = { }
+            for aa_i, proc_signal in proc_signals.items():
+                if 0 <= self.central_core_ch < proc_signal.shape[0]:
+                    proc_signal = np.append(
+                            proc_signal[:self.central_core_ch],
+                            proc_signal[self.central_core_ch+1:-1]
+                    )
+                # get the appropriate calibration matrix
+                C_aa_i = self.aa_cal( f"AA{aa_i}" ) if isinstance( aa_i, int ) else self.aa_cal( aa_i )
+
+                curvatures[ aa_i ] = C_aa_i @ proc_signal  # 2 x num_AA @ num_AA x 1
+
+            # for
+
+        # if
+
+        elif isinstance( proc_signals, np.ndarray ):
+            # initalize curvatures
+            if proc_signals.ndim == 1:
+                curvatures = np.zeros( (2, self.num_activeAreas) )
+            elif proc_signals.ndim == 2:
+                curvatures = np.zeros( (proc_signals.shape[ 0 ], 2, self.num_activeAreas) )
+            else:
+                raise IndexError( "'proc_signals' dimensions must be <= 2." )
+
+            for aa_i in range( 1, self.num_activeAreas + 1 ):
+                mask_aa_i = list( map(
+                        lambda aa, is_central_ch: (aa == aa_i) and (not is_central_ch),
+                        self.assignments_aa(), self.assignments_centralcore()
+                ) )
+
+                C_aa_i = self.aa_cal( f"AA{aa_i}" )
+
+                if proc_signals.ndim == 1:
+                    proc_signals_aa_i = proc_signals[ mask_aa_i ]
+                    curvatures[ :, aa_i - 1 ] = C_aa_i @ proc_signals_aa_i
+
+                # if
+
+                else:
+                    proc_signals_aa_i = proc_signals[ :, mask_aa_i ]
+                    curvatures[ :, :, aa_i - 1 ] = proc_signals_aa_i @ C_aa_i.T
+
+                # else
+            # for
+
+        # else
+
+        else:
+            raise TypeError( "'proc_signals' must be a 'dict' or 'numpy.ndarray'" )
+
+        # else
+
+        return curvatures
+
+    # curvatures_processed
+
     def temperature_compensate( self, proc_signals: np.ndarray, arg_check: bool = True ) -> np.ndarray:
         """ Perform temperature compensation using the central core for processed signals
 
@@ -1072,11 +1164,12 @@ def __get_argparser() -> argparse.ArgumentParser:
     material_grp.add_argument( '--poisson-ratio', type=float, default=None, help="The Poisson's ratio of the needle" )
 
     parser.add_argument( '--mcf-central-core-ch', type=int, default=None, help="MCF Central core channel. If not provided, will use standard FBGNeedle class.")
+    parser.add_argument( '--serial-number', type=str, default="{0:d}CH-{1:d}AA-{2:04d}", help="Override the serial number with formats {0}, {1}, and {2}")
     parser.add_argument( 'length', type=float, help='The entire length of the FBG needle' )
     parser.add_argument( 'num_channels', type=int, help='The number of channels in the FBG needle' )
 
     parser.add_argument( 'sensor_locations', type=float, nargs='+', help='Sensor locations from the tip of the needle' )
-    parser.add_argument( 'needle_num', type=int, help='The number of channels in the FBG needle' )
+    parser.add_argument( 'needle_num', type=int, help='The number of the FBG Needle' )
 
     return parser
 
@@ -1095,7 +1188,7 @@ def main( args=None ):
     aa_locs = (length - np.array( pargs.sensor_locations )).tolist()
 
     needle_num = pargs.needle_num
-    serial_number = "{:d}CH-{:d}AA-{:04d}".format( num_chs, len( aa_locs ), needle_num )
+    serial_number = pargs.serial_number.format( num_chs, len( aa_locs ), needle_num )
 
     directory = os.path.join( 'data', serial_number )
 
@@ -1125,7 +1218,6 @@ def main( args=None ):
     NeedleClass = FBGNeedle
     if central_core_ch is not None:
         NeedleClass = MCFNeedle
-        serial_number = f"MCF-{serial_number}"
 
     # if
 
@@ -1168,7 +1260,7 @@ def main( args=None ):
     print()
 
     if not os.path.isdir( directory ):
-        os.mkdir( directory, exist_ok=True )
+        os.mkdir( directory )
 
     # if
 
