@@ -1,4 +1,5 @@
 from needle_shape_sensing.tensorflow import (
     geometry,
-    numerical
+    numerical,
+    intrinsics,
 )
\ No newline at end of file
